@@ -2,7 +2,9 @@ import re, json
 from datetime import date
 from .https import idk
 requests = idk()
-get = idk().get
+def get(*args, **kwargs):
+    hmm = idk()
+    return hmm.get(headers=hmm.headers, *args, **kwargs)
 #cars of nitrotype
 cars = {
     1 : 'Lamborgotti Mephisto SS',
